==> ejc-purchasingmanagement-api-3.0.0-20220824.083805-200-sources.jar: com/ejianc/business/purchasingmanagement/hystrix/PurchaseListHystrix.java <==
package com.ejianc.business.purchasingmanagement.hystrix;


import com.ejianc.business.purchasingmanagement.api.PurchaseListApi;
import com.ejianc.business.purchasingmanagement.api.PurchaseListApi;
import com.ejianc.business.purchasingmanagement.vo.*;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

/**
 *
 *
 * @author liyongjia
 *
 */
@Component
public class PurchaseListHystrix implements PurchaseListApi {


	@Override
	public CommonResponse<PurchaseListApi> contractList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> receiptList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> transportersReceiptList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shippingList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> supplierinvoiceList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shippersinvoiceList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shipping(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> saveShipping(PurchasedetilVO PurchasedetilVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> deleteShipping(RequestVO RequestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> detailShipping(RequestVO RequestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}


	@Override
	public CommonResponse<PurchaseListApi> supplierShippingList(Request2VO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> contractListByID(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> contractTime() {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> contractTime1() {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> purchasereceiptDetil(PurchasereceiptVO purchasereceiptVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}


}

==> ejc-purchasingmanagement-api-3.0.0-20220829.133909-210-sources.jar: com/ejianc/business/purchasingmanagement/hystrix/PurchaseListHystrix.java <==
package com.ejianc.business.purchasingmanagement.hystrix;


import com.ejianc.business.purchasingmanagement.api.PurchaseListApi;
import com.ejianc.business.purchasingmanagement.api.PurchaseListApi;
import com.ejianc.business.purchasingmanagement.vo.*;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

/**
 *
 *
 * @author liyongjia
 *
 */
@Component
public class PurchaseListHystrix implements PurchaseListApi {


	@Override
	public CommonResponse<PurchaseListApi> contractList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> receiptList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> transportersReceiptList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shippingList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> supplierinvoiceList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shippersinvoiceList(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> shipping(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> saveShipping(PurchasedetilVO PurchasedetilVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> deleteShipping(RequestVO RequestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> detailShipping(RequestVO RequestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}


	@Override
	public CommonResponse<PurchaseListApi> supplierShippingList(Request2VO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> contractListByID(RequestVO requestVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> contractTime() {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> orderingSchedulesTime() {
		return CommonResponse.error("网络问题， 保存失败。");
	}

	@Override
	public CommonResponse<PurchaseListApi> purchasereceiptDetil(PurchasereceiptVO purchasereceiptVO) {
		return CommonResponse.error("网络问题， 保存失败。");
	}


}
